@@ -256,7 +256,7 @@ class ConfigurationBase():
         """
         config = cls.load(name)
         #table = stylus.create_table(config.items(), self.show_columns, indexed=False)
-        table = stylus.create_formated_dict(config, cls.show_columns, indexed=False)
+        table = stylus.create_formatted_dict(config, cls.show_columns, indexed=False)
         print(table)  
         
     @classmethod
