@@ -27,6 +27,31 @@ class ProjectConfiguration(ConfigurationBase):
     def __init__(self):
         self.project_config = {}
         super().__init__()
+        
+    @staticmethod
+    def get_parser_test():
+        parser, subparsers = ConfigurationBase.get_parser_test(
+            description='Manage a project for hyperparamter optimization',
+            usage='hpogrid project <action> <project_name> [<options>')
+        for action in subparsers.choices:
+            subparsers.choices[action].usage = subparsers.choices[action].usage.replace('<config_type>', 'project')
+        for action in ['create', 'update', 'recreate']:
+            parser_action = subparsers.choices.get(action, None)
+            if parser_action is None:
+                raise RuntimeError('Subparser {} not found'.format(action))
+            parser_action.add_argument('name', help= "Name given to the project")
+            parser_action.add_argument('-p','--scripts_path', metavar='',
+                help='Path to the location of training scripts'
+                ' (or the directory containing the training scripts)')
+            parser_action.add_argument('-o','--hpo_config', metavar='',
+                help='Name of the hpo configuration to use')
+            parser_action.add_argument('-g','--grid_config', metavar='',
+                help='Name of the grid configuration to use')
+            parser_action.add_argument('-m','--model_config', metavar='',
+                help='Name of the model configuration to use')
+            parser_action.add_argument('-s','--search_space', metavar='',
+                help='Name of the search space configuration to use')
+        return parser
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()           
