@@ -35,7 +35,7 @@ def create_table(data, columns=None, indexed=True, transpose=False,
         stralign=stralign)
     return table
 
-def create_formated_dict(data, columns=None, indexed=True, transpose=False,
+def create_formatted_dict(data, columns=None, indexed=True, transpose=False,
     tableformat=kDefaultTableStyle, stralign=kDefaultStrAlign):
     _data = copy.deepcopy(data)
     if isinstance(_data, dict):
